@@ -14,7 +14,6 @@
 #include "kalarmcalendar/identities.h"
 #include "kalarm_debug.h"
 
-#include <kpimtextedit/kpimtextedit-texttospeech.h>
 #include <KLocalizedString>
 
 #include <QCommandLineParser>
@@ -59,7 +58,7 @@ enum Option
     REMINDER,
     REMINDER_ONCE,
     REPEAT,
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
     SPEAK,
 #endif
     SUBJECT,
@@ -244,7 +243,7 @@ QStringList CommandOptions::setOptions(QCommandLineParser* parser, const QString
               = new QCommandLineOption(QStringList{QStringLiteral("r"), QStringLiteral("repeat")},
                                        i18n("Number of times to repeat alarm (including initial occasion)"),
                                        QStringLiteral("count"));
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
     mOptions[SPEAK]
               = new QCommandLineOption(QStringList{QStringLiteral("s"), QStringLiteral("speak")},
                                        i18n("Speak the message when it is displayed"));
@@ -476,7 +475,7 @@ void CommandOptions::process()
     d->checkEditType(EditAlarmDlg::DISPLAY, EditAlarmDlg::AUDIO, PLAY);
     d->checkEditType(EditAlarmDlg::DISPLAY, EditAlarmDlg::AUDIO, PLAY_REPEAT);
     d->checkEditType(EditAlarmDlg::DISPLAY, EditAlarmDlg::AUDIO, VOLUME);
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
     d->checkEditType(EditAlarmDlg::DISPLAY, SPEAK);
 #endif
     d->checkEditType(EditAlarmDlg::DISPLAY, BEEP);
@@ -631,7 +630,7 @@ void CommandOptions::process()
                     d->setErrorIncompatible(PLAY, PLAY_REPEAT);
                 if (mParser->isSet(*mOptions.at(BEEP)))
                     d->setErrorIncompatible(BEEP, opt);
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
                 else if (mParser->isSet(*mOptions.at(SPEAK)))
                     d->setErrorIncompatible(SPEAK, opt);
 #endif
@@ -647,7 +646,7 @@ void CommandOptions::process()
             }
             else if (mParser->isSet(*mOptions.at(VOLUME)))
                 d->setErrorRequires(VOLUME, PLAY, PLAY_REPEAT);
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
             if (mParser->isSet(*mOptions.at(SPEAK)))
             {
                 if (mParser->isSet(*mOptions.at(BEEP)))
@@ -706,7 +705,7 @@ void CommandOptions::process()
                 mFlags |= KAEvent::AUTO_CLOSE;
             if (mParser->isSet(*mOptions.at(BEEP)))
                 mFlags |= KAEvent::BEEP;
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
             if (mParser->isSet(*mOptions.at(SPEAK)))
                 mFlags |= KAEvent::SPEAK;
 #endif
@@ -769,7 +768,7 @@ void CommandOptions::process()
                 errors << d->optionName(REMINDER);
             if (mParser->isSet(*mOptions.at(REMINDER_ONCE)))
                 errors << d->optionName(REMINDER_ONCE);
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
             if (mParser->isSet(*mOptions.at(SPEAK)))
                 errors << d->optionName(SPEAK);
 #endif
